==> igniteui-react-charts-16.6.8.tgz: package/ES5/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var PercentagePriceOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(PercentagePriceOscillatorIndicator, _super);
    function PercentagePriceOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentagePriceOscillatorIndicator.prototype.get_p5 = function () {
        return new PercentagePriceOscillatorIndicatorStrategy();
    };
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "p5", {
        get: function () {
            return this.get_p5();
        },
        enumerable: true,
        configurable: true
    });
    PercentagePriceOscillatorIndicator.prototype.get_qi = function () {
        return PercentagePriceOscillatorIndicator.$;
    };
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "qi", {
        get: function () {
            return this.get_qi();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qr));
        },
        set: function (a) {
            this.h(PercentagePriceOscillatorIndicator.qr, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentagePriceOscillatorIndicator.prototype.qd = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qq));
        },
        set: function (a) {
            this.h(PercentagePriceOscillatorIndicator.qq, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentagePriceOscillatorIndicator.prototype.qa = function () {
        return this.longPeriod;
    };
    PercentagePriceOscillatorIndicator.$t = markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentagePriceOscillatorIndicator.qr = StrategyBasedIndicator.qp(10, PercentagePriceOscillatorIndicator.$);
    PercentagePriceOscillatorIndicator.qq = StrategyBasedIndicator.ql(30, PercentagePriceOscillatorIndicator.$);
    return PercentagePriceOscillatorIndicator;
}(StrategyBasedIndicator));
export { PercentagePriceOscillatorIndicator };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/PercentagePriceOscillatorIndicator.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { StrategyBasedIndicator } from "./StrategyBasedIndicator";
import { IShortPeriodLongPeriod_$type } from "./IShortPeriodLongPeriod";
import { PercentagePriceOscillatorIndicatorStrategy } from "./PercentagePriceOscillatorIndicatorStrategy";
import { typeGetValue, markType } from "igniteui-react-core/ES5/type";
/**
 * @hidden
 */
var PercentagePriceOscillatorIndicator = /** @class */ (function (_super) {
    tslib_1.__extends(PercentagePriceOscillatorIndicator, _super);
    function PercentagePriceOscillatorIndicator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    PercentagePriceOscillatorIndicator.prototype.get_qc = function () {
        return new PercentagePriceOscillatorIndicatorStrategy();
    };
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "qc", {
        get: function () {
            return this.get_qc();
        },
        enumerable: true,
        configurable: true
    });
    PercentagePriceOscillatorIndicator.prototype.get_qp = function () {
        return PercentagePriceOscillatorIndicator.$;
    };
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "qp", {
        get: function () {
            return this.get_qp();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "shortPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qy));
        },
        set: function (a) {
            this.h(PercentagePriceOscillatorIndicator.qy, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentagePriceOscillatorIndicator.prototype.qk = function () {
        return this.shortPeriod;
    };
    Object.defineProperty(PercentagePriceOscillatorIndicator.prototype, "longPeriod", {
        get: function () {
            return typeGetValue(this.c(PercentagePriceOscillatorIndicator.qx));
        },
        set: function (a) {
            this.h(PercentagePriceOscillatorIndicator.qx, a);
        },
        enumerable: true,
        configurable: true
    });
    PercentagePriceOscillatorIndicator.prototype.qh = function () {
        return this.longPeriod;
    };
    PercentagePriceOscillatorIndicator.$t = markType(PercentagePriceOscillatorIndicator, 'PercentagePriceOscillatorIndicator', StrategyBasedIndicator.$, [IShortPeriodLongPeriod_$type]);
    PercentagePriceOscillatorIndicator.qy = StrategyBasedIndicator.qw(10, PercentagePriceOscillatorIndicator.$);
    PercentagePriceOscillatorIndicator.qx = StrategyBasedIndicator.qs(30, PercentagePriceOscillatorIndicator.$);
    return PercentagePriceOscillatorIndicator;
}(StrategyBasedIndicator));
export { PercentagePriceOscillatorIndicator };
